@@ -21,13 +21,17 @@ def roll_die(_die: _Die_Faces_) -> int:
 class Dice:
     """Define a Die object instance"""
 
-    def __init__(self, name: str, sides: int, val: int = None) -> None:
+    def __init__(self, sides: int, name: str = None, val: int = None) -> None:
         """Initial the Die object & set a face value"""
         # Verify that the die will have at least 2 options
         if sides < 2:
             raise ValueError(
                 "Number of sides for a valid die needs to be greater than 2"
             )
+        # Check if we need to generate a dice name
+        if name is None:
+            # Genrate the Dn dice name string
+            name = f"D{str(sides)}"
         # Create the die face values from 1 to sides +1 because range end is exclusive
         face_values: _Die_Faces_ = [*range(1, sides + 1)]
         # Check if an initial die face value is set
@@ -67,11 +71,11 @@ class Dice:
 
     def __copy__(self):
         """Create a copy of the dice object"""
-        return __class__(name=self.__name, sides=len(self), val=self.__rolled)
+        return __class__(sides=len(self), name=self.__name, val=self.__rolled)
 
     def __repr__(self) -> str:
         """Get a string to represent recreating this object"""
-        return f"{__class__}(name={self.__name},sides={len(self)},val={self.__rolled})"
+        return f"{__class__}(sides={len(self)},name={self.__name},val={self.__rolled})"
 
     def __str__(self) -> str:
         """Get the object as a human readable string"""
@@ -198,12 +202,12 @@ class DiceShaker:
     def __str__(self) -> str:
         """Get the object as a human readable string"""
         # TODO work out how to collect the rolled values to add the strings
-        return f"\n".join(
+        return "\n".join(
             [
                 f"Rolled : {len(self)} Dice",
                 f"Minimum : {self.min_roll}",
                 f"Maximum : {self.max_roll}",
-                f"\n".join([str(d) for d in self.__dice]),
+                "\n".join([str(d) for d in self.__dice]),
                 f"Total : {self.roll_total}",
             ]
         )
@@ -239,9 +243,13 @@ class DiceShaker:
 
 def main() -> None:
     """Main function to run the application"""
-    d: Dice = Dice("D15", 15)
-    print("Dice(D15)")
-    print(d, d < 15, d > 0, sep="\n")
+    import sys
+
+    args = sys.argv[1:]
+    print(args)
+    die_sides = 15
+    d: Dice = Dice(die_sides)
+    print(f"Dice(D{die_sides})", d, d < die_sides, d > 0, sep="\n")
     print("Rolls...", d.roll())
     shaker: DiceShaker = DiceShaker([copy(d), copy(d), copy(d)])
     print("New Shaker", shaker, sep="\n")
